==> vss-ui-4.141.4.tgz: package/Components/ItemIndicator/ItemIndicator.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { IconButton } from "office-ui-fabric-react/lib/Button";
import { TooltipHost, TooltipOverflowMode } from '../../Tooltip';
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { VssIcon } from '../../VssIcon';
import "./ItemIndicator.css";
var ItemIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ItemIndicator, _super);
    function ItemIndicator(props) {
        var _this = _super.call(this, props) || this;
        _this._onClick = function (ev) {
            var _a = _this.props, item = _a.item, onClick = _a.onClick;
            if (onClick) {
                onClick(ev, item);
                ev.preventDefault();
            }
        };
        _this._onItemChanged = function (state) {
            _this.setState({
                title: state.title,
                iconProps: state.iconProps
            });
        };
        _this.state = _this._buildNewState(_this.props);
        return _this;
    }
    /**
     * This gets executed when a container component re-renders ItemIndicator.
     * @param nextProps New props.
     */
    ItemIndicator.prototype.componentWillReceiveProps = function (nextProps) {
        this.setState(this._buildNewState(nextProps));
    };
    ItemIndicator.prototype.componentDidMount = function () {
        if (this.props.item) {
            this.props.item.subscribe(this._onItemChanged);
        }
    };
    ItemIndicator.prototype.componentDidUpdate = function (prevProps, prevState) {
        if (this.props.item !== prevProps.item) {
            // If item changed, we need to subscribe for new item
            if (this.props.item) {
                this.props.item.subscribe(this._onItemChanged);
            }
            // We need to unsubscribe prev item
            if (prevProps.item) {
                prevProps.item.unsubscribe(this._onItemChanged);
            }
        }
    };
    ItemIndicator.prototype.componentWillUnmount = function () {
        if (this.props.item) {
            this.props.item.unsubscribe(this._onItemChanged);
        }
    };
    /**
     * Builds a new state using the specified props.
     */
    ItemIndicator.prototype._buildNewState = function (props) {
        if (props.item) {
            var itemState = props.item.getState();
            return {
                title: itemState.title,
                iconProps: itemState.iconProps
            };
        }
        else {
            return {
                title: props.title,
                iconProps: props.iconProps
            };
        }
    };
    ItemIndicator.prototype.render = function () {
        var _a = this.state, title = _a.title, iconProps = _a.iconProps;
        var _b = this.props, onClick = _b.onClick, className = _b.className, onRender = _b.onRender, item = _b.item;
        var overflowMode;
        var indicator;
        var itemIndicatorClassName = "vss-ItemIndicator flex-noshrink flex-self-center";
        if (onRender) {
            return onRender();
        }
        if (iconProps) {
            title = title || iconProps.title;
            // We need to remove title from props since it will be shown as a tooltip host below
            indicator = React.createElement(VssIcon, tslib_1.__assign({}, tslib_1.__assign({}, iconProps, { title: undefined, className: css(iconProps.className, className, { itemIndicatorClassName: !onClick && !title }) })));
        }
        else {
            overflowMode = TooltipOverflowMode.Parent;
            indicator = React.createElement("div", { className: css(className, { itemIndicatorClassName: !onClick && !title }) }, title);
        }
        if (onClick) {
            indicator = React.createElement(IconButton, { className: css({ itemIndicatorClassName: !title }), onClick: this._onClick, ariaLabel: title }, indicator);
        }
        if (title) {
            indicator = React.createElement(TooltipHost, { hostClassName: itemIndicatorClassName, content: title, overflowMode: overflowMode }, indicator);
        }
        return indicator;
    };
    return ItemIndicator;
}(BaseComponent));
export { ItemIndicator };
var ItemIndicatorSet = /** @class */ (function (_super) {
    tslib_1.__extends(ItemIndicatorSet, _super);
    function ItemIndicatorSet() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._onClick = function (ev) {
            if (!ev.isDefaultPrevented() && _this.props.onClick) {
                _this.props.onClick(ev);
            }
        };
        return _this;
    }
    ItemIndicatorSet.prototype.render = function () {
        var indicators = this.props.indicators;
        if (indicators && indicators.length) {
            var list = indicators.map(function (indicatorProps, index) { return React.createElement(ItemIndicator, tslib_1.__assign({}, indicatorProps, { key: "ItemIndicator$" + index })); });
            return (React.createElement("div", { className: "vss-IndicatorSet flex-row", onClick: this._onClick }, list));
        }
        return null;
    };
    return ItemIndicatorSet;
}(BaseComponent));
export { ItemIndicatorSet };

==> vss-ui-4.142.1.tgz: package/Components/ItemIndicator/ItemIndicator.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { Button } from '../../Button';
import { TooltipHost, TooltipOverflowMode } from '../../Tooltip';
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { VssIcon } from '../../VssIcon';
import "./ItemIndicator.css";
var ItemIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ItemIndicator, _super);
    function ItemIndicator(props) {
        var _this = _super.call(this, props) || this;
        _this._onClick = function (ev) {
            var _a = _this.props, item = _a.item, onClick = _a.onClick;
            if (onClick) {
                onClick(ev, item);
                ev.preventDefault();
            }
        };
        _this._onItemChanged = function (state) {
            _this.setState({
                title: state.title,
                iconProps: state.iconProps
            });
        };
        _this.state = _this._buildNewState(_this.props);
        return _this;
    }
    /**
     * This gets executed when a container component re-renders ItemIndicator.
     * @param nextProps New props.
     */
    ItemIndicator.prototype.componentWillReceiveProps = function (nextProps) {
        this.setState(this._buildNewState(nextProps));
    };
    ItemIndicator.prototype.componentDidMount = function () {
        if (this.props.item) {
            this.props.item.subscribe(this._onItemChanged);
        }
    };
    ItemIndicator.prototype.componentDidUpdate = function (prevProps, prevState) {
        if (this.props.item !== prevProps.item) {
            // If item changed, we need to subscribe for new item
            if (this.props.item) {
                this.props.item.subscribe(this._onItemChanged);
            }
            // We need to unsubscribe prev item
            if (prevProps.item) {
                prevProps.item.unsubscribe(this._onItemChanged);
            }
        }
    };
    ItemIndicator.prototype.componentWillUnmount = function () {
        if (this.props.item) {
            this.props.item.unsubscribe(this._onItemChanged);
        }
    };
    /**
     * Builds a new state using the specified props.
     */
    ItemIndicator.prototype._buildNewState = function (props) {
        if (props.item) {
            var itemState = props.item.getState();
            return {
                title: itemState.title,
                iconProps: itemState.iconProps
            };
        }
        else {
            return {
                title: props.title,
                iconProps: props.iconProps
            };
        }
    };
    ItemIndicator.prototype.render = function () {
        var _a = this.state, title = _a.title, iconProps = _a.iconProps;
        var _b = this.props, onClick = _b.onClick, className = _b.className, onRender = _b.onRender, item = _b.item;
        var overflowMode;
        var indicator;
        var itemIndicatorClassName = "vss-ItemIndicator flex-noshrink flex-self-center";
        if (onRender) {
            return onRender();
        }
        if (iconProps) {
            title = title || iconProps.title;
            // We need to remove title from props since it will be shown as a tooltip host below
            indicator = React.createElement(VssIcon, tslib_1.__assign({}, tslib_1.__assign({}, iconProps, { title: undefined, className: css(iconProps.className, className, { itemIndicatorClassName: !onClick && !title }) })));
        }
        else {
            overflowMode = TooltipOverflowMode.Parent;
            indicator = React.createElement("div", { className: css(className, { itemIndicatorClassName: !onClick && !title }) }, title);
        }
        if (onClick) {
            indicator = React.createElement(Button, { className: css({ itemIndicatorClassName: !title }), onClick: this._onClick, ariaLabel: title }, indicator);
        }
        if (title) {
            indicator = React.createElement(TooltipHost, { hostClassName: itemIndicatorClassName, content: title, overflowMode: overflowMode }, indicator);
        }
        return indicator;
    };
    return ItemIndicator;
}(BaseComponent));
export { ItemIndicator };
var ItemIndicatorSet = /** @class */ (function (_super) {
    tslib_1.__extends(ItemIndicatorSet, _super);
    function ItemIndicatorSet() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._onClick = function (ev) {
            if (!ev.isDefaultPrevented() && _this.props.onClick) {
                _this.props.onClick(ev);
            }
        };
        return _this;
    }
    ItemIndicatorSet.prototype.render = function () {
        var indicators = this.props.indicators;
        if (indicators && indicators.length) {
            var list = indicators.map(function (indicatorProps, index) { return React.createElement(ItemIndicator, tslib_1.__assign({}, indicatorProps, { key: "ItemIndicator$" + index })); });
            return (React.createElement("div", { className: "vss-IndicatorSet flex-row", onClick: this._onClick }, list));
        }
        return null;
    };
    return ItemIndicatorSet;
}(BaseComponent));
export { ItemIndicatorSet };
